@@ -28,7 +28,7 @@ class StateMachineGenerator:
         "Specify either 'Role' or 'Policies' (but not both at the same time) or neither of them"
     )
 
-    def __init__(  # type: ignore[no-untyped-def] # noqa: too-many-arguments
+    def __init__(  # type: ignore[no-untyped-def] # noqa: PLR0913
         self,
         logical_id,
         depends_on,
